package training.samples.osgi.xrepo;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Map;

import org.jboss.osgi.repository.XRepository;
import org.jboss.osgi.resolver.MavenCoordinates;
import org.osgi.resource.Capability;
import org.osgi.resource.Requirement;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class SampleRepository implements XRepository {

	private static Logger LOG = LoggerFactory.getLogger(SampleRepository.class);
	
	@Override
	public Map<Requirement, Collection<Capability>> findProviders(Collection<? extends Requirement> requirements) {
		log(requirements);
		return Collections.EMPTY_MAP;
	}
	
	@Override
	public Collection<Capability> findProviders(Requirement requirement) {
		log(Arrays.asList(requirement));
		return Collections.EMPTY_LIST;
	}
	
	@Override
	public String getName() {
		return "SampleRepository";
	}
	
	private void log(Collection<? extends Requirement> requirements) {
		StringBuilder sb = new StringBuilder("findProviders for ");
		for (Requirement req: requirements) {
	        String namespace = req.getNamespace();
	        List<Capability> result = new ArrayList<Capability>();
	        if (MAVEN_IDENTITY_NAMESPACE.equals(namespace)) {
	            String mavenId = (String) req.getAttributes().get(MAVEN_IDENTITY_NAMESPACE);
	            MavenCoordinates coordinates = MavenCoordinates.parse(mavenId);
	            sb.append(coordinates.toExternalForm()).append(' ');
	        }
		}
		LOG.info(sb.toString());
	}
	
}
